@@ -22,7 +22,7 @@
 #endif
 
 #ifndef QCORODBUS_DEPRECATED
-#  define QCORODBUS_DEPRECATED 
+#  define QCORODBUS_DEPRECATED __attribute__ ((__deprecated__))
 #endif
 
 #ifndef QCORODBUS_DEPRECATED_EXPORT
